Re: svn commit: r362998 - in head: stand/defaults sys/amd64/amd64 sys/powerpc/aim sys/vm

2020-07-07 Thread Alexey Dokuchaev
On Tue, Jul 07, 2020 at 08:33:12PM +, Scott Long wrote:
> New Revision: 362998
> URL: https://svnweb.freebsd.org/changeset/base/362998
> 
> Log:
>   Migrate the feature of excluding RAM pages to use "excludelist"
>   as its nomenclature.

Did I miss any prior discussion of this change?  Commit references no
DR or something.  I thought we had agreed that this black/master type
of commits should not just go in like one pleases.

To me this change is pessimization, it is technically less accurate.

./danfe
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r363002 - head/usr.sbin/bluetooth/hccontrol

2020-07-07 Thread Takanori Watanabe
Author: takawata
Date: Wed Jul  8 03:57:47 2020
New Revision: 363002
URL: https://svnweb.freebsd.org/changeset/base/363002

Log:
  Add le_rand command.
  
  PR: 247808
  Submitted by: Marc Veldman

Modified:
  head/usr.sbin/bluetooth/hccontrol/hccontrol.8
  head/usr.sbin/bluetooth/hccontrol/le.c

Modified: head/usr.sbin/bluetooth/hccontrol/hccontrol.8
==
--- head/usr.sbin/bluetooth/hccontrol/hccontrol.8   Wed Jul  8 02:28:08 
2020(r363001)
+++ head/usr.sbin/bluetooth/hccontrol/hccontrol.8   Wed Jul  8 03:57:47 
2020(r363002)
@@ -164,6 +164,7 @@ are:
 .It Cm LE_Connect
 .It Cm LE_Read_Channel_Map
 .It Cm LE_Read_Remote_Features
+.It Cm LE_Rand
 .El
 .Pp
 The currently supported node commands in

Modified: head/usr.sbin/bluetooth/hccontrol/le.c
==
--- head/usr.sbin/bluetooth/hccontrol/le.c  Wed Jul  8 02:28:08 2020
(r363001)
+++ head/usr.sbin/bluetooth/hccontrol/le.c  Wed Jul  8 03:57:47 2020
(r363002)
@@ -71,6 +71,7 @@ static int le_connect(int s, int argc, char *argv[]);
 static void handle_le_connection_event(ng_hci_event_pkt_t* e, bool verbose);
 static int le_read_channel_map(int s, int argc, char *argv[]);
 static void handle_le_remote_features_event(ng_hci_event_pkt_t* e);
+static int le_rand(int s, int argc, char *argv[]);
 
 static int
 le_set_scan_param(int s, int argc, char *argv[])
@@ -1211,8 +1212,33 @@ static void handle_le_remote_features_event(ng_hci_eve
return;
 } /* handle_le_remote_features_event */
 
+static int le_rand(int s, int argc, char *argv[])
+{
+   ng_hci_le_rand_rp rp;
+   int n;
 
+   n = sizeof(rp);
 
+   if (hci_simple_request(s, NG_HCI_OPCODE(NG_HCI_OGF_LE,
+   NG_HCI_OCF_LE_RAND), 
+   (void *), ) == ERROR)
+   return (ERROR);
+   
+   if (rp.status != 0x00) {
+   fprintf(stdout, "Status: %s [%#02x]\n", 
+   hci_status2str(rp.status), rp.status);
+   return (FAILED);
+   }
+
+   fprintf(stdout,
+   "Random number : %08llx\n",
+   (unsigned long long)le64toh(rp.random_number));
+
+   return (OK);
+}
+
+
+
 struct hci_command le_commands[] = {
 {
"le_enable",
@@ -1335,5 +1361,11 @@ struct hci_command le_commands[] = {
  "Read supported features for the device\n"
  "identified by the connection handle",
  _read_remote_features
+  },
+  {
+ "le_rand",
+ "le_rand\n"
+ "Generate 64 bits of random data",
+ _rand
   },
 };
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r363001 - head/sys/fs/nfsclient

2020-07-07 Thread Rick Macklem
Author: rmacklem
Date: Wed Jul  8 02:28:08 2020
New Revision: 363001
URL: https://svnweb.freebsd.org/changeset/base/363001

Log:
  Add support for ext_pgs mbufs to nfsm_uiombuf().
  
  This patch uses a slightly different algorithm for the non-ext_pgs case,
  where a variable called "mcp" is maintained, pointing to the current
  location that mbuf data can be filled into. This avoids use of
  mtod(mp, char *) + mp->m_len to calculate the location, since this does
  not work for ext_pgs mbufs and I think it makes the algorithm more readable.
  This change should not result in semantic changes for the non-ext_pgs case.
  
  This is another in the series of commits that add support to the NFS client
  and server for building RPC messages in ext_pgs mbufs with anonymous pages.
  This is useful so that the entire mbuf list does not need to be
  copied before calling sosend() when NFS over TLS is enabled.
  
  Since ND_EXTPG is never set yet, there is no semantic change at this time.

Modified:
  head/sys/fs/nfsclient/nfs_clcomsubs.c

Modified: head/sys/fs/nfsclient/nfs_clcomsubs.c
==
--- head/sys/fs/nfsclient/nfs_clcomsubs.c   Wed Jul  8 01:47:20 2020
(r363000)
+++ head/sys/fs/nfsclient/nfs_clcomsubs.c   Wed Jul  8 02:28:08 2020
(r363001)
@@ -62,7 +62,7 @@ nfsm_uiombuf(struct nfsrv_descript *nd, struct uio *ui
struct mbuf *mp, *mp2;
int xfer, left, mlen;
int uiosiz, clflg, rem;
-   char *cp, *tcp;
+   char *mcp, *tcp;
 
KASSERT(uiop->uio_iovcnt == 1, ("nfsm_uiotombuf: iovcnt != 1"));
 
@@ -72,41 +72,52 @@ nfsm_uiombuf(struct nfsrv_descript *nd, struct uio *ui
clflg = 0;
rem = NFSM_RNDUP(siz) - siz;
mp = mp2 = nd->nd_mb;
+   mcp = nd->nd_bpos;
while (siz > 0) {
+   KASSERT((nd->nd_flag & ND_EXTPG) != 0 || mcp ==
+   mtod(mp, char *) + mp->m_len, ("nfsm_uiombuf: mcp wrong"));
left = uiop->uio_iov->iov_len;
uiocp = uiop->uio_iov->iov_base;
if (left > siz)
left = siz;
uiosiz = left;
while (left > 0) {
-   mlen = M_TRAILINGSPACE(mp);
-   if (mlen == 0) {
-   if (clflg)
-   NFSMCLGET(mp, M_WAITOK);
-   else
-   NFSMGET(mp);
-   mp->m_len = 0;
-   mp2->m_next = mp;
-   mp2 = mp;
+   if ((nd->nd_flag & ND_EXTPG) != 0)
+   mlen = nd->nd_bextpgsiz;
+   else
mlen = M_TRAILINGSPACE(mp);
+   if (mlen == 0) {
+   if ((nd->nd_flag & ND_EXTPG) != 0) {
+   mp = nfsm_add_ext_pgs(mp,
+   nd->nd_maxextsiz, >nd_bextpg);
+   mcp = (char *)(void *)PHYS_TO_DMAP(
+ mp->m_epg_pa[nd->nd_bextpg]);
+   nd->nd_bextpgsiz = PAGE_SIZE;
+   } else {
+   if (clflg)
+   NFSMCLGET(mp, M_WAITOK);
+   else
+   NFSMGET(mp);
+   mp->m_len = 0;
+   mlen = M_TRAILINGSPACE(mp);
+   mcp = mtod(mp, char *);
+   mp2->m_next = mp;
+   mp2 = mp;
+   }
}
xfer = (left > mlen) ? mlen : left;
-#ifdef notdef
-   /* Not Yet.. */
-   if (uiop->uio_iov->iov_op != NULL)
-   (*(uiop->uio_iov->iov_op))
-   (uiocp, mtod(mp, caddr_t) + mp->m_len,
-   xfer);
-   else
-#endif
if (uiop->uio_segflg == UIO_SYSSPACE)
-   NFSBCOPY(uiocp, mtod(mp, caddr_t) + mp->m_len,
-   xfer);
+   NFSBCOPY(uiocp, mcp, xfer);
else
-   copyin(uiocp, mtod(mp, caddr_t) + mp->m_len, xfer);
+   copyin(uiocp, mcp, xfer);
mp->m_len += xfer;
left -= xfer;
uiocp += xfer;
+   mcp += xfer;
+   if ((nd->nd_flag & ND_EXTPG) != 0) {
+ 

svn commit: r363000 - head/usr.bin/calendar/calendars

2020-07-07 Thread Greg Lehey
Author: grog
Date: Wed Jul  8 01:47:20 2020
New Revision: 363000
URL: https://svnweb.freebsd.org/changeset/base/363000

Log:
  Be more precise about Percy Grainger's place of birth.

Modified:
  head/usr.bin/calendar/calendars/calendar.music

Modified: head/usr.bin/calendar/calendars/calendar.music
==
--- head/usr.bin/calendar/calendars/calendar.music  Tue Jul  7 20:42:35 
2020(r362999)
+++ head/usr.bin/calendar/calendars/calendar.music  Wed Jul  8 01:47:20 
2020(r363000)
@@ -287,7 +287,7 @@
 07/06  The Jefferson Airplane is formed in San Francisco, 1965
 07/07  Ringo Starr (Richard Starkey) born in Liverpool, England, 1940
 07/07  Leo Sowerby dies in Port Clinton, Ohio, 1968
-07/08  Percy Grainger is born near Melbourne, Australia, 1882
+07/08  Percy Grainger is born in Brighton, Victoria, Australia, 1882
 07/08  Hans Leo Hassler is born in Nuremberg, Germany, 1564
 07/09  Ottorino Respighi is born in Bologna, Italy, 1879
 07/09  Randall Thompson dies, 1984
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r362998 - in head: stand/defaults sys/amd64/amd64 sys/powerpc/aim sys/vm

2020-07-07 Thread Mark Millard via svn-src-head
Beyond being a breaking change for existing /boot/blacklist.txt
files, there is the non-operation issue:

. . .
+ram_excludelist_type="ram_excludelist" # Required for the kernel to find
# the blacklist module
. . .

In other words, it is still using the term blacklist in one place
(and not explicitly as a reference to the prior naming convention
to help avoid any potential confusions).

===
Mark Millard
marklmi at yahoo.com
( dsl-only.net went
away in early 2018-Mar)

___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r362998 - in head: stand/defaults sys/amd64/amd64 sys/powerpc/aim sys/vm

2020-07-07 Thread Oliver Pinter
On Tuesday, July 7, 2020, Scott Long  wrote:

> Author: scottl
> Date: Tue Jul  7 20:33:11 2020
> New Revision: 362998
> URL: https://svnweb.freebsd.org/changeset/base/362998
>
> Log:
>   Migrate the feature of excluding RAM pages to use "excludelist"
>   as its nomenclature.
>
>   MFC after:1 week
>
> Modified:
>   head/stand/defaults/loader.conf
>   head/sys/amd64/amd64/pmap.c
>   head/sys/powerpc/aim/mmu_radix.c
>   head/sys/vm/vm_page.c
>   head/sys/vm/vm_page.h
>
> Modified: head/stand/defaults/loader.conf
> 
> ==
> --- head/stand/defaults/loader.conf Tue Jul  7 19:09:38 2020
> (r362997)
> +++ head/stand/defaults/loader.conf Tue Jul  7 20:33:11 2020
> (r362998)
> @@ -49,12 +49,12 @@ entropy_cache_type="boot_entropy_cache" #
> Required for
> # must not change value even if the
> # _name above does change!
>
> -###  RAM Blacklist configuration  
> -ram_blacklist_load="NO"# Set this to YES to load
> a file
> +###  RAM Excludelist configuration  
> +ram_excludelist_load="NO"  # Set this to YES to load a file
> # containing a list of addresses to
> # exclude from the running system.
> -ram_blacklist_name="/boot/blacklist.txt" # Set this to the name of the
> file
> -ram_blacklist_type="ram_blacklist" # Required for the kernel to find
> +ram_excludeist_name="/boot/excludelist.txt" # Set this to the name of
> the file
> +ram_excludelist_type="ram_excludelist" # Required for the kernel to find


This will break systems where the blacklist file is already in use. At
least please add this to release notes and provide a backward compatible
way.



> # the blacklist module
>
>  ###  Microcode loading configuration  
>
> Modified: head/sys/amd64/amd64/pmap.c
> 
> ==
> --- head/sys/amd64/amd64/pmap.c Tue Jul  7 19:09:38 2020(r362997)
> +++ head/sys/amd64/amd64/pmap.c Tue Jul  7 20:33:11 2020(r362998)
> @@ -2060,7 +2060,7 @@ pmap_init(void)
> int error, i, ret, skz63;
>
> /* L1TF, reserve page @0 unconditionally */
> -   vm_page_blacklist_add(0, bootverbose);
> +   vm_page_excludelist_add(0, bootverbose);
>
> /* Detect bare-metal Skylake Server and Skylake-X. */
> if (vm_guest == VM_GUEST_NO && cpu_vendor_id == CPU_VENDOR_INTEL &&
> @@ -2081,7 +2081,7 @@ pmap_init(void)
> printf("SKZ63: skipping 4M RAM starting "
> "at physical 1G\n");
> for (i = 0; i < atop(0x40); i++) {
> -   ret = vm_page_blacklist_add(0x4000 +
> +   ret = vm_page_excludelist_add(0x4000 +
> ptoa(i), FALSE);
> if (!ret && bootverbose)
> printf("page at %#lx already
> used\n",
>
> Modified: head/sys/powerpc/aim/mmu_radix.c
> 
> ==
> --- head/sys/powerpc/aim/mmu_radix.cTue Jul  7 19:09:38 2020
> (r362997)
> +++ head/sys/powerpc/aim/mmu_radix.cTue Jul  7 20:33:11 2020
> (r362998)
> @@ -3557,7 +3557,7 @@ mmu_radix_init()
> int error, i, pv_npg;
>
> /* L1TF, reserve page @0 unconditionally */
> -   vm_page_blacklist_add(0, bootverbose);
> +   vm_page_excludelist_add(0, bootverbose);
>
> zone_radix_pgd = uma_zcache_create("radix_pgd_cache",
> RADIX_PGD_SIZE, NULL, NULL,
>
> Modified: head/sys/vm/vm_page.c
> 
> ==
> --- head/sys/vm/vm_page.c   Tue Jul  7 19:09:38 2020(r362997)
> +++ head/sys/vm/vm_page.c   Tue Jul  7 20:33:11 2020(r362998)
> @@ -155,10 +155,11 @@ vm_page_t vm_page_array;
>  long vm_page_array_size;
>  long first_page;
>
> -static TAILQ_HEAD(, vm_page) blacklist_head;
> -static int sysctl_vm_page_blacklist(SYSCTL_HANDLER_ARGS);
> -SYSCTL_PROC(_vm, OID_AUTO, page_blacklist, CTLTYPE_STRING | CTLFLAG_RD |
> -CTLFLAG_MPSAFE, NULL, 0, sysctl_vm_page_blacklist, "A", "Blacklist
> pages");
> +static TAILQ_HEAD(, vm_page) excludelist_head;
> +static int sysctl_vm_page_excludelist(SYSCTL_HANDLER_ARGS);
> +SYSCTL_PROC(_vm, OID_AUTO, page_excludelist, CTLTYPE_STRING | CTLFLAG_RD |
> +CTLFLAG_MPSAFE, NULL, 0, sysctl_vm_page_excludelist, "A",
> +"Blacklist pages");
>
>  static uma_zone_t fakepg_zone;
>
> @@ -258,16 +259,16 @@ vm_set_page_size(void)
>  }
>
>  /*
> - * vm_page_blacklist_next:
> + * 

svn commit: r362999 - head/stand/defaults

2020-07-07 Thread Scott Long
Author: scottl
Date: Tue Jul  7 20:42:35 2020
New Revision: 362999
URL: https://svnweb.freebsd.org/changeset/base/362999

Log:
  Fix a example/docs typo from r362998, no functional change.

Modified:
  head/stand/defaults/loader.conf

Modified: head/stand/defaults/loader.conf
==
--- head/stand/defaults/loader.conf Tue Jul  7 20:33:11 2020
(r362998)
+++ head/stand/defaults/loader.conf Tue Jul  7 20:42:35 2020
(r362999)
@@ -53,7 +53,7 @@ entropy_cache_type="boot_entropy_cache"   # Required for
 ram_excludelist_load="NO"  # Set this to YES to load a file
# containing a list of addresses to
# exclude from the running system.
-ram_excludeist_name="/boot/excludelist.txt" # Set this to the name of the file
+ram_excludelist_name="/boot/excludelist.txt" # Set this to the name of the file
 ram_excludelist_type="ram_excludelist" # Required for the kernel to find
# the blacklist module
 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r362998 - in head: stand/defaults sys/amd64/amd64 sys/powerpc/aim sys/vm

2020-07-07 Thread Scott Long
Author: scottl
Date: Tue Jul  7 20:33:11 2020
New Revision: 362998
URL: https://svnweb.freebsd.org/changeset/base/362998

Log:
  Migrate the feature of excluding RAM pages to use "excludelist"
  as its nomenclature.
  
  MFC after:1 week

Modified:
  head/stand/defaults/loader.conf
  head/sys/amd64/amd64/pmap.c
  head/sys/powerpc/aim/mmu_radix.c
  head/sys/vm/vm_page.c
  head/sys/vm/vm_page.h

Modified: head/stand/defaults/loader.conf
==
--- head/stand/defaults/loader.conf Tue Jul  7 19:09:38 2020
(r362997)
+++ head/stand/defaults/loader.conf Tue Jul  7 20:33:11 2020
(r362998)
@@ -49,12 +49,12 @@ entropy_cache_type="boot_entropy_cache" # Required for
# must not change value even if the
# _name above does change!
 
-###  RAM Blacklist configuration  
-ram_blacklist_load="NO"# Set this to YES to load a file
+###  RAM Excludelist configuration  
+ram_excludelist_load="NO"  # Set this to YES to load a file
# containing a list of addresses to
# exclude from the running system.
-ram_blacklist_name="/boot/blacklist.txt" # Set this to the name of the file
-ram_blacklist_type="ram_blacklist" # Required for the kernel to find
+ram_excludeist_name="/boot/excludelist.txt" # Set this to the name of the file
+ram_excludelist_type="ram_excludelist" # Required for the kernel to find
# the blacklist module
 
 ###  Microcode loading configuration  

Modified: head/sys/amd64/amd64/pmap.c
==
--- head/sys/amd64/amd64/pmap.c Tue Jul  7 19:09:38 2020(r362997)
+++ head/sys/amd64/amd64/pmap.c Tue Jul  7 20:33:11 2020(r362998)
@@ -2060,7 +2060,7 @@ pmap_init(void)
int error, i, ret, skz63;
 
/* L1TF, reserve page @0 unconditionally */
-   vm_page_blacklist_add(0, bootverbose);
+   vm_page_excludelist_add(0, bootverbose);
 
/* Detect bare-metal Skylake Server and Skylake-X. */
if (vm_guest == VM_GUEST_NO && cpu_vendor_id == CPU_VENDOR_INTEL &&
@@ -2081,7 +2081,7 @@ pmap_init(void)
printf("SKZ63: skipping 4M RAM starting "
"at physical 1G\n");
for (i = 0; i < atop(0x40); i++) {
-   ret = vm_page_blacklist_add(0x4000 +
+   ret = vm_page_excludelist_add(0x4000 +
ptoa(i), FALSE);
if (!ret && bootverbose)
printf("page at %#lx already used\n",

Modified: head/sys/powerpc/aim/mmu_radix.c
==
--- head/sys/powerpc/aim/mmu_radix.cTue Jul  7 19:09:38 2020
(r362997)
+++ head/sys/powerpc/aim/mmu_radix.cTue Jul  7 20:33:11 2020
(r362998)
@@ -3557,7 +3557,7 @@ mmu_radix_init()
int error, i, pv_npg;
 
/* L1TF, reserve page @0 unconditionally */
-   vm_page_blacklist_add(0, bootverbose);
+   vm_page_excludelist_add(0, bootverbose);
 
zone_radix_pgd = uma_zcache_create("radix_pgd_cache",
RADIX_PGD_SIZE, NULL, NULL,

Modified: head/sys/vm/vm_page.c
==
--- head/lib/csu/Makefile.inc   Tue Jul  7 17:02:23 2020(r362994)
+++ head/lib/csu/Makefile.inc   Tue Jul  7 18:19:05 2020(r362995)
@@ -37,7 +37,7 @@ CLEANFILES+=  ${OBJS} ${CRT1OBJS} crt1_c.o gcrt1_c.o Sc
 crt1.o:crt1_c.o ${CRT1OBJS}
${LD} ${_LDFLAGS} -o ${.TARGET} -r ${.ALLSRC:M*.o}
 .if ${MACHINE_ARCH} == "i386"
-   ${OBJCOPY} --localize-symbol _start1 crt1.o
+   ${OBJCOPY} --localize-symbol _start1 ${.TARGET}
 .endif
 
 gcrt1_c.o: crt1_c.c
@@ -52,7 +52,7 @@ Scrt1_c.o: crt1_c.c
 Scrt1.o: Scrt1_c.o ${CRT1OBJS}
${LD} ${_LDFLAGS} -o ${.TARGET} -r ${.ALLSRC:M*.o}
 .if ${MACHINE_ARCH} == "i386"
-   ${OBJCOPY} --localize-symbol _start1 crt1.o
+   ${OBJCOPY} --localize-symbol _start1 ${.TARGET}
 .endif
 
 crtbegin.o: crtbegin.c
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r362902 - in head/lib/csu: . aarch64 amd64 arm i386 mips powerpc powerpc64 riscv

2020-07-07 Thread John Baldwin
On 7/3/20 2:46 PM, Kjell Tore Ullavik wrote:
> 
> Got a buildworld error for CURRENT, amd64 today. I have not rebuilt in 
> while, but maybe r362902 is related?

Yes, it is a bug in that commit.  I'll commit a fix once it's been
reviewed.  Thanks!

-- 
John Baldwin
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r362994 - head/usr.bin/timeout

2020-07-07 Thread Fernando Apesteguía
Author: fernape (ports committer)
Date: Tue Jul  7 17:02:23 2020
New Revision: 362994
URL: https://svnweb.freebsd.org/changeset/base/362994

Log:
  timeout(1): Add EXAMPLES section
  
  Small EXAMPLES section showing the use of -s, -k and the different exit values
  
  Approved by:  manpages (gbe)
  Differential Revision:https://reviews.freebsd.org/D25575

Modified:
  head/usr.bin/timeout/timeout.1

Modified: head/usr.bin/timeout/timeout.1
==
--- head/usr.bin/timeout/timeout.1  Tue Jul  7 16:35:52 2020
(r362993)
+++ head/usr.bin/timeout/timeout.1  Tue Jul  7 17:02:23 2020
(r362994)
@@ -26,7 +26,7 @@
 .\"
 .\" $FreeBSD$
 .\"
-.Dd March 28, 2018
+.Dd July 7, 2020
 .Dt TIMEOUT 1
 .Os
 .Sh NAME
@@ -136,6 +136,62 @@ If an invalid parameter is passed to
 or
 .Fl k ,
 the exit status returned is 125.
+.Sh EXAMPLES
+Run
+.Xr sleep 1
+with a time limit of 4 seconds.
+Since the command completes in 2 seconds, the exit status is 0:
+.Bd -literal -offset indent
+$ timeout 4 sleep 2
+$ echo $?
+0
+.Ed
+.Pp
+Run
+.Xr sleep 1
+for 4 seconds and terminate process after 2 seconds.
+124 is returned since no
+.Fl -preserve-status
+is used:
+.Bd -literal -offset indent
+$ timeout 2 sleep 4
+$ echo $?
+124
+.Ed
+.Pp
+Same as above but preserving status.
+Exit status is 128 + signal number (15 for
+.Va SIGTERM )
+.Bd -literal -offset indent
+$ timeout --preserve-status 2 sleep 4
+$ echo $?
+143
+.Ed
+.Pp
+Same as above but sending
+.Va SIGALRM
+(signal number 14) instead of
+.Va SIGTERM
+.Bd -literal -offset indent
+$ timeout --preserve-status -s SIGALRM 2 sleep 4
+$ echo $?
+142
+.Ed
+.Pp
+Try to
+.Xr fetch 1
+the single page version of the
+.Fx
+Handbook.
+Send a
+.Va SIGTERM
+signal after 1 minute and send a
+.Va SIGKILL
+signal 5 seconds later if the process refuses to stop:
+.Bd -literal -offset indent
+timeout -k 5s 1m fetch \\
+https://www.freebsd.org/doc/en_US.ISO8859-1/books/handbook/book.html
+.Ed
 .Sh SEE ALSO
 .Xr kill 1 ,
 .Xr signal 3
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r362993 - head/sys/conf

2020-07-07 Thread Mark Johnston
Author: markj
Date: Tue Jul  7 16:35:52 2020
New Revision: 362993
URL: https://svnweb.freebsd.org/changeset/base/362993

Log:
  Rebuild sysent when capabilities.conf is updated.
  
  Reviewed by:  brooks
  Sponsored by: The FreeBSD Foundation
  Differential Revision:https://reviews.freebsd.org/D25571

Modified:
  head/sys/conf/sysent.mk

Modified: head/sys/conf/sysent.mk
==
--- head/sys/conf/sysent.mk Tue Jul  7 16:07:39 2020(r362992)
+++ head/sys/conf/sysent.mk Tue Jul  7 16:35:52 2020(r362993)
@@ -22,6 +22,13 @@ SYSENT_CONF?=syscalls.conf
 SRCS+= ${SYSENT_FILE}
 SRCS+= ${SYSENT_CONF}
 
+# Ensure that the target gets updated if the capabilities file is modified,
+# even though it is not an explicit input to makesyscalls.lua.  For some
+# targets, like Linux system calls, this is unnecessary, but a spurious rebuild
+# is both rare and harmless.
+CAPABILITIES_CONF?= ${SYSDIR}/kern/capabilities.conf
+SRCS+= ${CAPABILITIES_CONF}
+
 MAKESYSCALLS_INTERP?=  ${LUA}
 MAKESYSCALLS_SCRIPT?=  ${SYSDIR}/tools/makesyscalls.lua
 MAKESYSCALLS=  ${MAKESYSCALLS_INTERP} ${MAKESYSCALLS_SCRIPT}
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r362992 - head/usr.bin/time

2020-07-07 Thread Fernando Apesteguía
Author: fernape (ports committer)
Date: Tue Jul  7 16:07:39 2020
New Revision: 362992
URL: https://svnweb.freebsd.org/changeset/base/362992

Log:
  time(1): Add EXAMPLES section
  
  Add EXAMPLES showing all five flags: -a, -h, -l, -o, -p
  
  Approved by:  manpages (bcr)

Modified:
  head/usr.bin/time/time.1

Modified: head/usr.bin/time/time.1
==
--- head/usr.bin/time/time.1Tue Jul  7 13:51:16 2020(r362991)
+++ head/usr.bin/time/time.1Tue Jul  7 16:07:39 2020(r362992)
@@ -28,7 +28,7 @@
 .\" @(#)time.1 8.1 (Berkeley) 6/6/93
 .\" $FreeBSD$
 .\"
-.Dd May 14, 2006
+.Dd July 7, 2020
 .Dt TIME 1
 .Os
 .Sh NAME
@@ -129,6 +129,62 @@ If
 .Nm
 encounters any other error, the exit status is between 1 and 125
 included.
+.Sh EXAMPLES
+Time the execution of
+.Xr ls 1
+on an empty directory:
+.Bd -literal -offset indent
+$ /usr/bin/time ls
+0.00 real 0.00 user 0.00 sys
+.Ed
+.Pp
+Time the execution of the
+.Xr cp 1
+command and store the result in the
+.Pa times.txt
+file.
+Then execute the command again to make a new copy and add the result to the 
same
+file:
+.Bd -literal -offset indent
+$ /usr/bin/time -o times.txt cp FreeBSD-12.1-RELEASE-amd64-bootonly.iso 
copy1.iso
+$ /usr/bin/time -a -o times.txt cp FreeBSD-12.1-RELEASE-amd64-bootonly.iso 
copy2.iso
+.Ed
+.Pp
+The
+.Pa times.txt
+file will contain the times of both commands:
+.Bd -literal -offset indent
+$ cat times.txt
+0.68 real 0.00 user 0.22 sys
+0.67 real 0.00 user 0.21 sys
+.Ed
+.Pp
+Time the
+.Xr sleep 1
+command and show the results in a human friendly format.
+Show the contents of the
+.Em rusage
+structure too:
+.Bd -literal -offset indent
+$ /usr/bin/time -l -h -p sleep 5
+real 5.01
+user 0.00
+sys 0.00
+ 0  maximum resident set size
+ 0  average shared memory size
+ 0  average unshared data size
+ 0  average unshared stack size
+80  page reclaims
+ 0  page faults
+ 0  swaps
+ 1  block input operations
+ 0  block output operations
+ 0  messages sent
+ 0  messages received
+ 0  signals received
+ 3  voluntary context switches
+ 0  involuntary context switches
+.Ed
 .Sh SEE ALSO
 .Xr builtin 1 ,
 .Xr csh 1 ,
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r362989 - head/stand/libsa/geli

2020-07-07 Thread Toomas Soome
Author: tsoome
Date: Tue Jul  7 12:24:40 2020
New Revision: 362989
URL: https://svnweb.freebsd.org/changeset/base/362989

Log:
  loader: geli_dev_ioctl does return huge mediasize
  
  The DIOCGMEDIASIZE is calculated md->md_sectorsize * md->md_provsize, and
  for boot disk, the md_sectorsize is 4k. However, the md_provsize is already
  in units of bytes.
  
  Sponsored by: Netflix, Klara Inc.

Modified:
  head/stand/libsa/geli/gelidev.c

Modified: head/stand/libsa/geli/gelidev.c
==
--- head/stand/libsa/geli/gelidev.c Tue Jul  7 12:10:59 2020
(r362988)
+++ head/stand/libsa/geli/gelidev.c Tue Jul  7 12:24:40 2020
(r362989)
@@ -219,7 +219,7 @@ geli_dev_ioctl(struct open_file *f, u_long cmd, void *
*(u_int *)data = md->md_sectorsize;
break;
case DIOCGMEDIASIZE:
-   *(uint64_t *)data = md->md_sectorsize * md->md_provsize;
+   *(uint64_t *)data = md->md_provsize;
break;
default:
return (ENOTTY);
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r362988 - head/sys/netinet

2020-07-07 Thread Richard Scheffenegger
Author: rscheff
Date: Tue Jul  7 12:10:59 2020
New Revision: 362988
URL: https://svnweb.freebsd.org/changeset/base/362988

Log:
  Fix KASSERT during tcp_newtcpcb when low on memory
  
  While testing with system default cc set to cubic, and
  running a memory exhaustion validation, FreeBSD panics for a
  missing inpcb reference / lock.
  
  Reviewed by:  rgrimes (mentor), tuexen (mentor)
  Approved by:  rgrimes (mentor), tuexen (mentor)
  MFC after:3 weeks
  Sponsored by: NetApp, Inc.
  Differential Revision:https://reviews.freebsd.org/D25583

Modified:
  head/sys/netinet/tcp_subr.c

Modified: head/sys/netinet/tcp_subr.c
==
--- head/sys/netinet/tcp_subr.c Tue Jul  7 07:51:09 2020(r362987)
+++ head/sys/netinet/tcp_subr.c Tue Jul  7 12:10:59 2020(r362988)
@@ -1702,6 +1702,12 @@ tcp_newtcpcb(struct inpcb *inp)
KASSERT(!STAILQ_EMPTY(_list), ("cc_list is empty!"));
CC_ALGO(tp) = CC_DEFAULT();
CC_LIST_RUNLOCK();
+   /*
+* The tcpcb will hold a reference on its inpcb until tcp_discardcb()
+* is called.
+*/
+   in_pcbref(inp); /* Reference for tcpcb */
+   tp->t_inpcb = inp;
 
if (CC_ALGO(tp)->cb_init != NULL)
if (CC_ALGO(tp)->cb_init(tp->ccv) > 0) {
@@ -1746,12 +1752,6 @@ tcp_newtcpcb(struct inpcb *inp)
if (V_tcp_do_sack)
tp->t_flags |= TF_SACK_PERMIT;
TAILQ_INIT(>snd_holes);
-   /*
-* The tcpcb will hold a reference on its inpcb until tcp_discardcb()
-* is called.
-*/
-   in_pcbref(inp); /* Reference for tcpcb */
-   tp->t_inpcb = inp;
 
/*
 * Init srtt to TCPTV_SRTTBASE (0), so we can tell that we have no
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r362987 - in head: contrib/bc usr.bin/gh-bc

2020-07-07 Thread Hartmann, O.
On Tue, 7 Jul 2020 07:51:10 + (UTC)
Stefan Eßer  wrote:

> Author: se
> Date: Tue Jul  7 07:51:09 2020
> New Revision: 362987
> URL: https://svnweb.freebsd.org/changeset/base/362987
> 
> Log:
>   Update to version 3.1.1
>   
>   This version fixes a regression with regard to tradtional behavior
> of the non-standard FreeBSD option "-e". In the previous version "-e
> quit" caused bc to exit before any computations had been performed,
> since all -e option parameters were concatenated and parsed as a
> whole, with quit causing the program to exit as soon as it was
> parsed. This version parses and executes commands passed with -e one
> by one and only exits after all prior commands have been executed.
>   
>   This commit is not a SVN merge, since the vendor import had been
> performed after the import to contrib. Instead the contents of
> contrib/bc has been removed and the new version is copied over
> unchanged from vendor/bc/dist.
> 
> Replaced:
>   head/contrib/bc/
>  - copied from r362986, vendor/bc/dist/
> Modified:
>   head/usr.bin/gh-bc/Makefile
> 
> Modified: head/usr.bin/gh-bc/Makefile
> ==
> --- head/usr.bin/gh-bc/Makefile   Tue Jul  7 07:32:15
> 2020  (r362986) +++ head/usr.bin/gh-bc/Makefile   Tue Jul
> 7 07:51:09 2020   (r362987) @@ -19,6 +19,7 @@ LINKS=
>   ${BINDIR}/bc ${BINDIR}/dc 
>  CATALOGS=en_US.UTF-8
>  CATALOGS+=   de_DE.UTF-8 de_DE.ISO8859-1
> +CATALOGS+=   es_ES.UTF-8 es_ES.ISO8859-1
>  CATALOGS+=   fr_FR.UTF-8 fr_FR.ISO8859-1
>  CATALOGS+=   ja_JP.UTF-8 ja_JP.eucJP
>  CATALOGS+=   nl_NL.UTF-8 nl_NL.ISO8859-1
> @@ -37,8 +38,7 @@ CFLAGS+=-DBC_ENABLE_PROMPT
>  CFLAGS+= -DBC_ENABLE_LONG_OPTIONS
>  CFLAGS+= -DBC_ENABLE_EXTRA_MATH
>  CFLAGS+= -DBC_ENABLE_HISTORY
> -CFLAGS+= -DBC_ENABLE_SIGNALS=0
> -CFLAGS+= -DBC_NUM_KARATSUBA_LEN=64
> +CFLAGS+= -DBC_ENABLE_RAND
>  CFLAGS+= -DDC_ENABLED
>  CFLAGS+= -DNDEBUG
>  CFLAGS+= -DVERSION=${BCVERSION}
> @@ -46,8 +46,12 @@ CFLAGS+=   -I${BCDIR}/include
>  
>  .if ${MK_NLS_CATALOGS} == "no"
>  CFLAGS+= -DBC_ENABLE_NLS=0
> +MAN_SRC_BC=  bc/N.1
> +MAN_SRC_DC=  dc/N.1
>  .else
>  CFLAGS+= -DBC_ENABLE_NLS=1
> +MAN_SRC_BC=  bc/A.1
> +MAN_SRC_DC=  dc/A.1
>  
>  # prevent floating point incompatibilities caused by -flto on some
> architectures .if ${MACHINE_ARCH} != mips && ${MACHINE_ARCH} !=
> mips64 && \ @@ -73,6 +77,8 @@ NLSLINKS_de_DE.UTF-8+=
> de_AT.UTF-8 de_CH.UTF-8 NLSLINKS_de_DE.ISO8859-1+= de_AT.ISO8859-1
> de_CH.ISO8859-1 NLSLINKS_de_DE.ISO8859-1+= de_AT.ISO8859-15
> de_CH.ISO8859-15 de_DE.ISO8859-15 
> +NLSLINKS_es_ES.ISO8859-1+= es_ES.ISO8859-15
> +
>  NLSLINKS_fr_FR.UTF-8+=   fr_BE.UTF-8 fr_CA.UTF-8 fr_CH.UTF-8
>  NLSLINKS_fr_FR.ISO8859-1+= fr_BE.ISO8859-1 fr_CA.ISO8859-1
> fr_CH.ISO8859-1 NLSLINKS_fr_FR.ISO8859-1+= fr_BE.ISO8859-15
> fr_CA.ISO8859-15 fr_CH.ISO8859-15 \ @@ -97,5 +103,11 @@
> bc_help.c:bc_help.txt 
>  dc_help.c:   dc_help.txt
>   cd ${BCDIR} && sh gen/strgen.sh gen/dc_help.txt
> ${.OBJDIR}/dc_help.c dc_help dc.h +
> +bc.1:
> + ${CP} ${BCDIR}/manuals/${MAN_SRC_BC} ${.OBJDIR}/bc.1
> +
> +dc.1:
> + ${CP} ${BCDIR}/manuals/${MAN_SRC_DC} ${.OBJDIR}/dc.1
>  
>  .include 
> ___
> svn-src-head@freebsd.org mailing list
> https://lists.freebsd.org/mailman/listinfo/svn-src-head
> To unsubscribe, send any mail to
> "svn-src-head-unsubscr...@freebsd.org"

Thank you very much for this effort.

Kind regards,

O. Hartmann


pgpOEwTb33cWy.pgp
Description: OpenPGP digital signature


svn commit: r362987 - in head: contrib/bc usr.bin/gh-bc

2020-07-07 Thread Stefan Eßer
Author: se
Date: Tue Jul  7 07:51:09 2020
New Revision: 362987
URL: https://svnweb.freebsd.org/changeset/base/362987

Log:
  Update to version 3.1.1
  
  This version fixes a regression with regard to tradtional behavior of the
  non-standard FreeBSD option "-e". In the previous version "-e quit" caused
  bc to exit before any computations had been performed, since all -e option
  parameters were concatenated and parsed as a whole, with quit causing the
  program to exit as soon as it was parsed. This version parses and executes
  commands passed with -e one by one and only exits after all prior commands
  have been executed.
  
  This commit is not a SVN merge, since the vendor import had been performed
  after the import to contrib. Instead the contents of contrib/bc has been
  removed and the new version is copied over unchanged from vendor/bc/dist.

Replaced:
  head/contrib/bc/
 - copied from r362986, vendor/bc/dist/
Modified:
  head/usr.bin/gh-bc/Makefile

Modified: head/usr.bin/gh-bc/Makefile
==
--- head/usr.bin/gh-bc/Makefile Tue Jul  7 07:32:15 2020(r362986)
+++ head/usr.bin/gh-bc/Makefile Tue Jul  7 07:51:09 2020(r362987)
@@ -19,6 +19,7 @@ LINKS=${BINDIR}/bc ${BINDIR}/dc
 
 CATALOGS=  en_US.UTF-8
 CATALOGS+= de_DE.UTF-8 de_DE.ISO8859-1
+CATALOGS+= es_ES.UTF-8 es_ES.ISO8859-1
 CATALOGS+= fr_FR.UTF-8 fr_FR.ISO8859-1
 CATALOGS+= ja_JP.UTF-8 ja_JP.eucJP
 CATALOGS+= nl_NL.UTF-8 nl_NL.ISO8859-1
@@ -37,8 +38,7 @@ CFLAGS+=  -DBC_ENABLE_PROMPT
 CFLAGS+=   -DBC_ENABLE_LONG_OPTIONS
 CFLAGS+=   -DBC_ENABLE_EXTRA_MATH
 CFLAGS+=   -DBC_ENABLE_HISTORY
-CFLAGS+=   -DBC_ENABLE_SIGNALS=0
-CFLAGS+=   -DBC_NUM_KARATSUBA_LEN=64
+CFLAGS+=   -DBC_ENABLE_RAND
 CFLAGS+=   -DDC_ENABLED
 CFLAGS+=   -DNDEBUG
 CFLAGS+=   -DVERSION=${BCVERSION}
@@ -46,8 +46,12 @@ CFLAGS+= -I${BCDIR}/include
 
 .if ${MK_NLS_CATALOGS} == "no"
 CFLAGS+=   -DBC_ENABLE_NLS=0
+MAN_SRC_BC=bc/N.1
+MAN_SRC_DC=dc/N.1
 .else
 CFLAGS+=   -DBC_ENABLE_NLS=1
+MAN_SRC_BC=bc/A.1
+MAN_SRC_DC=dc/A.1
 
 # prevent floating point incompatibilities caused by -flto on some 
architectures
 .if ${MACHINE_ARCH} != mips && ${MACHINE_ARCH} != mips64 && \
@@ -73,6 +77,8 @@ NLSLINKS_de_DE.UTF-8+=de_AT.UTF-8 de_CH.UTF-8
 NLSLINKS_de_DE.ISO8859-1+= de_AT.ISO8859-1 de_CH.ISO8859-1
 NLSLINKS_de_DE.ISO8859-1+= de_AT.ISO8859-15 de_CH.ISO8859-15 de_DE.ISO8859-15
 
+NLSLINKS_es_ES.ISO8859-1+= es_ES.ISO8859-15
+
 NLSLINKS_fr_FR.UTF-8+= fr_BE.UTF-8 fr_CA.UTF-8 fr_CH.UTF-8
 NLSLINKS_fr_FR.ISO8859-1+= fr_BE.ISO8859-1 fr_CA.ISO8859-1 fr_CH.ISO8859-1
 NLSLINKS_fr_FR.ISO8859-1+= fr_BE.ISO8859-15 fr_CA.ISO8859-15 fr_CH.ISO8859-15 \
@@ -97,5 +103,11 @@ bc_help.c:  bc_help.txt
 
 dc_help.c: dc_help.txt
cd ${BCDIR} && sh gen/strgen.sh gen/dc_help.txt 
${.OBJDIR}/dc_help.c dc_help dc.h
+
+bc.1:
+   ${CP} ${BCDIR}/manuals/${MAN_SRC_BC} ${.OBJDIR}/bc.1
+
+dc.1:
+   ${CP} ${BCDIR}/manuals/${MAN_SRC_DC} ${.OBJDIR}/dc.1
 
 .include 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"
--- head/sys/vm/vm_page.c   Tue Jul  7 19:09:38 2020(r362997)
+++ head/sys/vm/vm_page.c   Tue Jul  7 20:33:11 2020(r362998)
@@ -155,10 +155,11 @@ vm_page_t vm_page_array;
 long vm_page_array_size;
 long first_page;
 
-static TAILQ_HEAD(, vm_page) blacklist_head;
-static int sysctl_vm_page_blacklist(SYSCTL_HANDLER_ARGS);
-SYSCTL_PROC(_vm, OID_AUTO, page_blacklist, CTLTYPE_STRING | CTLFLAG_RD |
-CTLFLAG_MPSAFE, NULL, 0, sysctl_vm_page_blacklist, "A", "Blacklist pages");
+static TAILQ_HEAD(, vm_page) excludelist_head;
+static int sysctl_vm_page_excludelist(SYSCTL_HANDLER_ARGS);
+SYSCTL_PROC(_vm, OID_AUTO, page_excludelist, CTLTYPE_STRING | CTLFLAG_RD |
+CTLFLAG_MPSAFE, NULL, 0, sysctl_vm_page_excludelist, "A",
+"Blacklist pages");
 
 static uma_zone_t fakepg_zone;
 
@@ -258,16 +259,16 @@ vm_set_page_size(void)
 }
 
 /*
- * vm_page_blacklist_next:
+ * vm_page_excludelist_next:
  *
  * Find the next entry in the provided string of blacklist
  * addresses.  Entries are separated by space, comma, or newline.
  * If an invalid integer is encountered then the rest of the
  * string is skipped.  Updates the list pointer to the next
  * character, or NULL 

svn commit: r362997 - in head/contrib/sqlite3: . tea

2020-07-07 Thread Cy Schubert
Author: cy
Date: Tue Jul  7 19:09:38 2020
New Revision: 362997
URL: https://svnweb.freebsd.org/changeset/base/362997

Log:
  MFV r362990:
  
  Update sqlite to 3.32.3 (3320300).
  
  Release Announcement: https://www.sqlite.org/releaselog/3_32_3.html
  See also: ports r541414
  
  PR:   247819
  Reported by:  Pavel Volkov 
  MFC after:1 week

Modified:
  head/contrib/sqlite3/configure
  head/contrib/sqlite3/configure.ac
  head/contrib/sqlite3/sqlite3.c
  head/contrib/sqlite3/sqlite3.h
  head/contrib/sqlite3/tea/configure
  head/contrib/sqlite3/tea/configure.ac
Directory Properties:
  head/contrib/sqlite3/   (props changed)

Modified: head/contrib/sqlite3/configure
==
--- head/contrib/sqlite3/configure  Tue Jul  7 18:37:06 2020
(r362996)
+++ head/contrib/sqlite3/configure  Tue Jul  7 19:09:38 2020
(r362997)
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for sqlite 3.32.2.
+# Generated by GNU Autoconf 2.69 for sqlite 3.32.3.
 #
 # Report bugs to .
 #
@@ -590,8 +590,8 @@ MAKEFLAGS=
 # Identity of this package.
 PACKAGE_NAME='sqlite'
 PACKAGE_TARNAME='sqlite'
-PACKAGE_VERSION='3.32.2'
-PACKAGE_STRING='sqlite 3.32.2'
+PACKAGE_VERSION='3.32.3'
+PACKAGE_STRING='sqlite 3.32.3'
 PACKAGE_BUGREPORT='http://www.sqlite.org'
 PACKAGE_URL=''
 
@@ -1341,7 +1341,7 @@ if test "$ac_init_help" = "long"; then
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures sqlite 3.32.2 to adapt to many kinds of systems.
+\`configure' configures sqlite 3.32.3 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1412,7 +1412,7 @@ fi
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
- short | recursive ) echo "Configuration of sqlite 3.32.2:";;
+ short | recursive ) echo "Configuration of sqlite 3.32.3:";;
esac
   cat <<\_ACEOF
 
@@ -1537,7 +1537,7 @@ fi
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-sqlite configure 3.32.2
+sqlite configure 3.32.3
 generated by GNU Autoconf 2.69
 
 Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1952,7 +1952,7 @@ cat >config.log <<_ACEOF
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by sqlite $as_me 3.32.2, which was
+It was created by sqlite $as_me 3.32.3, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
@@ -2818,7 +2818,7 @@ fi
 
 # Define the identity of the package.
  PACKAGE='sqlite'
- VERSION='3.32.2'
+ VERSION='3.32.3'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -14438,7 +14438,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by sqlite $as_me 3.32.2, which was
+This file was extended by sqlite $as_me 3.32.3, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES= $CONFIG_FILES
@@ -14495,7 +14495,7 @@ _ACEOF
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; 
s/[\\""\`\$]/&/g'`"
 ac_cs_version="\\
-sqlite config.status 3.32.2
+sqlite config.status 3.32.3
 configured by $0, generated by GNU Autoconf 2.69,
   with options \\"\$ac_cs_config\\"
 

Modified: head/contrib/sqlite3/configure.ac
==
--- head/contrib/sqlite3/configure.ac   Tue Jul  7 18:37:06 2020
(r362996)
+++ head/contrib/sqlite3/configure.ac   Tue Jul  7 19:09:38 2020
(r362997)
@@ -10,7 +10,7 @@
 #
 
 AC_PREREQ(2.61)
-AC_INIT(sqlite, 3.32.2, http://www.sqlite.org)
+AC_INIT(sqlite, 3.32.3, http://www.sqlite.org)
 AC_CONFIG_SRCDIR([sqlite3.c])
 AC_CONFIG_AUX_DIR([.])
 

Modified: head/contrib/sqlite3/sqlite3.c
==
--- head/contrib/sqlite3/sqlite3.c  Tue Jul  7 18:37:06 2020
(r362996)
+++ head/contrib/sqlite3/sqlite3.c  Tue Jul  7 19:09:38 2020
(r362997)
@@ -1,6 +1,6 @@
 /**
 ** This file is an amalgamation of many separate C source files from SQLite
-** version 3.32.2.  By combining all the individual C code files into this
+** version 3.32.3.  By combining all the individual C code files into this
 ** single large file, the entire code can be compiled as a single translation
 ** unit.  This allows many compilers to do optimizations that would not be
 ** possible if the files were compiled separately.  Performance improvements
@@ -1162,9 +1162,9 @@ extern "C" {
 ** 
@@ -258,16 +259,16 @@ vm_set_page_size(void)
  *
- * Find the next entry in the provided string of blacklist
+ * Find the next entry in the provided string of excludelist
  * addresses.  Entries are separated by space, comma, or newline.
  * If an invalid integer is encountered then the rest of the

svn commit: r362995 - head/lib/csu

2020-07-07 Thread John Baldwin
Author: jhb
Date: Tue Jul  7 18:19:05 2020
New Revision: 362995
URL: https://svnweb.freebsd.org/changeset/base/362995

Log:
  Invoke objcopy on the right object when building Scrt1.o on i386.
  
  This was a copy-paste bug in r362902.  While here, switch to using
  ${.TARGET}.
  
  Reported by:  Kjell Tore Ullavik 
  Reviewed by:  kib
  Sponsored by: DARPA
  Differential Revision:https://reviews.freebsd.org/D25585

Modified:
  head/lib/csu/Makefile.inc

Modified: head/lib/csu/Makefile.inc
==